@@ -396,6 +396,7 @@ every derived class for which alignment has a meaning should implement this meth
 
 /*!
 @param UIManager: the GtkUI%anager to populate.
+@param object: the Object on which occured the mouse click.
 
 This method is called to build a contextual menu for the object. It is called by Object::ShowContextualMenu, so
 it should not be necessary to call it directly. It should be overrided by derived classes when a contextual menu
@@ -403,7 +404,7 @@ is needed. Typically, each class adds a submenu and calls the same method for it
 Default implementation just calls the parent's method.
 @return true if something is added to the UIManager, false otherwise.
 */
-	virtual bool BuildContextualMenu (GtkUIManager *UIManager);
+	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
 
 /*!
 @param Signal: the appropriate SignalId
@@ -571,6 +572,12 @@ private:
 	Object *m_Parent;
 	map<string, Object*> m_Children; //string is Id of object, so each object must have an Id
 	set<Object*> m_Links; //objects linked to this but outside of the hierarchy
+
+protected:
+/*!
+Set to true while loading to avoid signal propagation.
+*/
+	bool m_IsLoading;
 };
 
 }
